<?php

/********************************************************************************************************************************
*
*  Steam group (/inc/plugins/steamgroup.php)
*  Author: Krzysztof "Supryk" Supryczyński
*  Copyright: © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*  
*  Website: http://supryk.eu/
*  Description: Show information about steam group on index and portal page in sidebox.
*
********************************************************************************************************************************/
/********************************************************************************************************************************
*
* This file is part of "Steam group" plugin for MyBB.
* Copyright © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
********************************************************************************************************************************/

if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}
$plugins->add_hook("admin_config_settings_manage", "steamgroup_admin_lang_load");
$plugins->add_hook("admin_config_settings_change", "steamgroup_admin_lang_load");
$plugins->add_hook("admin_config_settings_start", "steamgroup_admin_lang_load");
$plugins->add_hook("admin_style_templates_set", "steamgroup_admin_lang_load");
$plugins->add_hook("portal_end", "steamgroup_portal_end");
$plugins->add_hook("index_end", "steamgroup_index_end");
$plugins->add_hook("global_start", "steamgroup_global_start");
$plugins->add_hook("pre_output_page", "steamgroup_pre_output_page");


function steamgroup_info()
{
    global $lang;
    $lang->load("config_steamgroup");
	
	$lang->steamgroup_desc = "<form action=\"https://www.paypal.com/donate\" method=\"post\" target=\"_top\" style=\"float:right;\">
<input type=\"hidden\" name=\"hosted_button_id\" value=\"8YTUDFQN6XAGN\" />
<input type=\"image\" src=\"https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif\" border=\"0\" name=\"submit\" title=\"PayPal - The safer, easier way to pay online!\" alt=\"Donate with PayPal button\" />
<img alt=\"\" border=\"0\" src=\"https://www.paypal.com/en_PL/i/scr/pixel.gif\" width=\"1\" height=\"1\" />
</form>".$lang->steamgroup_desc;
	
	$information = array(
		"name"					=> $lang->steamgroup_name,
		"description"			=> $lang->steamgroup_desc,
		"website"				=> "http://supryk.eu/",
		"author"				=> "Krzysztof \"Supryk\" Supryczyński",
		"authorsite"			=> "http://supryk.eu/",
		"version"				=> "2.7",
		"compatibility"			=> "18*",
		"codename"				=> "steamgroup",
	);
	
	return $information;
}

function steamgroup_is_installed()
{
    global $db;
	
	$num_rows = $db->num_rows($db->simple_select("settinggroups", "*", "name=\"steamgroup\""));
	
	return $num_rows;
}

function steamgroup_install()
{
	global $db, $lang, $mybb, $cache, $page;
    $lang->load("config_steamgroup");
	
	if($mybb->request_method != 'post')
	{		
		$page->add_breadcrumb_item($lang->steamgroup_installing);
		$page->output_header($lang->steamgroup_plugins." - ".$lang->steamgroup_installing);
		
		$sub_tabs['steamgroup_installing'] = array( 
			'title' => $lang->steamgroup_installing,
			'link' => "index.php?module=config-plugins&action=activate&plugin=steamgroup&my_post_key={$mybb->post_code}", 
			'description' => $lang->steamgroup_installing_desc,
		);
		
		$page->output_nav_tabs($sub_tabs, 'steamgroup_installing');
		
		$form = new Form("index.php?module=config-plugins&action=activate&plugin=steamgroup&my_post_key={$mybb->post_code}", "post", "installing");
		
		if($mybb->get_input("errors"))
		{
			$errors = explode('|@|@|', $mybb->get_input("errors"));
			
			$page->output_inline_error($errors);
		}

		$form_container = new FormContainer($lang->steamgroup_installing." - ".$lang->steamgroup_installing_desc);
		$form_container->output_row($lang->setting_steamgroup_group_name."<em> *</em>", $lang->setting_steamgroup_group_name_desc, $form->generate_text_box('group_name', $mybb->get_input("group_name"), array('id' => 'group_name')), 'group_name');
		$form_container->end();

		$buttons[] = $form->generate_submit_button($lang->steamgroup_install_and_activate);

		$form->output_submit_wrapper($buttons);
		$form->end();

		$page->output_footer();
	}
	
	if(empty($mybb->get_input("group_name")))
	{
		$errors = $lang->steamgroup_missing_steam_group_name;
	}
	
	$contents = fetch_remote_file("http://steamcommunity.com/groups/{$mybb->get_input("group_name")}/memberslistxml/?xml=1.xml", $post_data);
	
	if(!$contents && empty($errors))
	{
		$errors = $lang->steamgroup_invslid_steam_group_name;
	}

	require_once MYBB_ROOT."inc/class_xml.php";
	$parser = new XMLParser($contents);
	$tree = $parser->get_tree();
	$data = array();
	$data['name'] = $tree['memberList']['groupDetails']['groupName']['value'];	
	
	if(empty($data['name']) && empty($errors))
	{
		$errors = $lang->steamgroup_invslid_steam_group_name;
	}
		
	if($errors)
	{
		$errors = implode('|@|@|', $errors);
				
		admin_redirect("index.php?module=config-plugins&action=activate&plugin=steamgroup&my_post_key={$mybb->post_code}&errors={$errors}&group_name={$mybb->input['group_name']}");
	}

		
	$max_disporder = $db->fetch_field($db->simple_select("settinggroups", "MAX(disporder) AS max_disporder"), "max_disporder");
	
	$settinggroups = array(
	//	"gid"				=> "",
		"name" 				=> "steamgroup", 
		"title"				=> $db->escape_string($lang->setting_group_steamgroup),
		"description" 		=> $db->escape_string($lang->setting_group_steamgroup_desc),
		"disporder" 		=> $max_disporder + 1,
		"isdefault" 		=> "0",
	);
	
	$gid = $db->insert_query("settinggroups", $settinggroups);
	
	$settings = array();
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "steamgroup_onoff",
		"title"				=> $db->escape_string($lang->setting_steamgroup_onoff),
		"description"	=> $db->escape_string($lang->setting_steamgroup_onoff_desc),
		"optionscode"	=> "yesno",
		"value"				=> "1",
		"disporder"		=> "1",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "steamgroup_portal_onoff",
		"title"				=> $db->escape_string($lang->setting_steamgroup_portal_onoff),
		"description"	=> $db->escape_string($lang->setting_steamgroup_portal_onoff_desc),
		"optionscode"	=> "yesno",
		"value"				=> "1",
		"disporder"		=> "2",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "steamgroup_index_onoff",
		"title"				=> $db->escape_string($lang->setting_steamgroup_index_onoff),
		"description"	=> $db->escape_string($lang->setting_steamgroup_index_onoff_desc),
		"optionscode"	=> "yesno",
		"value"				=> "1",
		"disporder"		=> "3",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);

	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "steamgroup_group_name",
		"title"				=> $db->escape_string($lang->setting_steamgroup_group_name),
		"description"	=> $db->escape_string($lang->setting_steamgroup_group_name_desc),
		"optionscode"	=> "text",
		"value"				=> $db->escape_string($mybb->get_input("group_name")),
		"disporder"		=> "4",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$db->insert_query_multiple("settings", $settings);
	
	rebuild_settings();
	
	$templategroup = array(
	//	"gid"			  		=> "",
		"prefix"       		=> "steamgroup",
		"title"            		=> $db->escape_string("<lang:steamgroup_templates>"),
	);
	
	$db->insert_query("templategroups", $templategroup);
		
	$templates = array();
		
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "steamgroup",
		"template" 		=> $db->escape_string('<table border="0" cellspacing="{$theme[\'borderwidth\']}" cellpadding="{$theme[\'tablespace\']}" class="tborder">
<tr>
<td class="thead" colspan="1">
<strong>{$lang->steamgroup_steamgroup}</strong>
</td>
</tr>
{$tpl[\'row\']}
</table>
<br />'),
		"sid" 				=> "-2",
		"version" 				=> "2.5",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "steamgroup_row",
		"template" 		=> $db->escape_string('<tr><td class="trow1">
<img src="{$data[\'avatar\']}" style="float: left;width: 108px;margin-right: 5px;"/>
<b>{$data[\'name\']}</b>{$data[\'shortname\']}<br/>
{$lang->steamgroup_members} {$data[\'members\']}<br/>
{$lang->steamgroup_online} {$data[\'online\']}<br/>
{$lang->steamgroup_ingame} {$data[\'ingame\']}<br/>
{$lang->steamgroup_inchat} {$data[\'inchat\']}<br/>
<a href="http://steamcommunity.com/groups/{$data[\'url\']}">{$lang->steamgroup_viewandjoin}</a> | <a href="steam://friends/joinchat/{$data[\'id\']}">{$lang->steamgroup_chat}</a>
</td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.5",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "steamgroup_row_noinformation",
		"template" 		=> $db->escape_string('<tr><td class="trow1" align="center">
{$lang->steamgroup_noinformation}
</td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.5",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$db->insert_query_multiple("templates", $templates);
	
	$query = $db->simple_select("tasks", "tid", "file='steamgroup'", array('limit' => '1'));
	
	if($db->num_rows($query) == 0)
	{
		require_once MYBB_ROOT."/inc/functions_task.php";
			
		$new_task = array(
			"title"			=> $db->escape_string($lang->steamgroup_task),
			"description" 	=> $db->escape_string($lang->steamgroup_task_desc),
			"file" 			=> "steamgroup",
			"minute" 		=> "0",
			"hour" 			=> "*",
			"day" 			=> "*",
			"month" 		=> "*",
			"weekday" 		=> "*",
			"enabled" 		=> "1",
			"logging" 		=> "1",
		);
	
		$new_task['nextrun'] = fetch_next_run($new_task);
		$tid = $db->insert_query("tasks", $new_task);
	
		$cache->update_tasks();
		run_task($tid);
	}
}

function steamgroup_uninstall()
{
    global $db, $cache;
	
	$db->delete_query("settinggroups", "name = \"steamgroup\"");
	$db->delete_query("settings", "name LIKE \"steamgroup%\"");
	rebuild_settings();
	$db->delete_query("templates", "title LIKE \"steamgroup%\"");
	$db->delete_query("tasks", "file = \"steamgroup\"");
	$cache->update_tasks();
	$cache->delete("steamgroup");
}

function steamgroup_admin_lang_load()
{
    global $lang;
    $lang->load("config_steamgroup");
} 

function steamgroup_portal_end()
{
	global $cache, $lang, $mybb, $templates, $theme, $steamgroup;
	$lang->load("steamgroup");
			
	if($mybb->settings['steamgroup_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['steamgroup_portal_onoff'] != "1")
	{
		return;
	}
	
	$tree = $cache->read("steamgroup");
	

	if(!empty($tree['name']))
	{
		$data['desc'] = $tree['desc'];
		$data['name'] = $tree['name'];
		$data['avatar'] = $tree['avatar'];
		$data['members'] = $tree['members'];
		$data['inchat'] = $tree['inchat'];
		$data['ingame'] = $tree['ingame'];
		$data['online'] = $tree['online'];
		$data['url'] = $tree['url'];
		$data['id'] = $tree['id'];
	
		eval("\$tpl['row'] = \"" . $templates->get("steamgroup_row") . "\";");
	}
	else
	{
		eval("\$tpl['row'] = \"" . $templates->get("steamgroup_row_noinformation") . "\";");
	}
	
	eval("\$steamgroup = \"".$templates->get("steamgroup")."\";");
}

function steamgroup_index_end()
{
	global $cache, $lang, $mybb, $templates, $theme, $steamgroup;
	$lang->load("steamgroup");
			
	if($mybb->settings['steamgroup_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['steamgroup_index_onoff'] != "1")
	{
		return;
	}
	
	$tree = $cache->read("steamgroup");
	

	if(!empty($tree['name']))
	{
		$data['desc'] = $tree['desc'];
		$data['name'] = $tree['name'];
		$data['avatar'] = $tree['avatar'];
		$data['members'] = $tree['members'];
		$data['inchat'] = $tree['inchat'];
		$data['ingame'] = $tree['ingame'];
		$data['online'] = $tree['online'];
		$data['url'] = $tree['url'];
		$data['id'] = $tree['id'];
	
		eval("\$tpl['row'] = \"" . $templates->get("steamgroup_row") . "\";");
	}
	else
	{
		eval("\$tpl['row'] = \"" . $templates->get("steamgroup_row_noinformation") . "\";");
	}
	
	eval("\$steamgroup = \"".$templates->get("steamgroup")."\";");
}

function update_steamgroup()
{
	global $cache, $mybb;
	
	$contents = fetch_remote_file("http://steamcommunity.com/groups/".$mybb->settings['steamgroup_group_name']."/memberslistxml/?xml=1.xml", $post_data);
	if($contents)
	{
		require_once MYBB_ROOT."inc/class_xml.php";
		$parser = new XMLParser($contents);
		$tree = $parser->get_tree();
		
		$data = array();
		
		$data['name'] = $tree['memberList']['groupDetails']['groupName']['value'];	
		$data['desc'] = $tree['memberList']['groupDetails']['headline']['value'];
		$data['avatar'] = $tree['memberList']['groupDetails']['avatarFull']['value'];
		$data['members'] = $tree['memberList']['groupDetails']['memberCount']['value'];
		$data['inchat'] = $tree['memberList']['groupDetails']['membersInChat']['value'];
		$data['ingame'] = $tree['memberList']['groupDetails']['membersInGame']['value'];
		$data['online'] = $tree['memberList']['groupDetails']['membersOnline']['value'];
		$data['url'] = $tree['memberList']['groupDetails']['groupURL']['value'];
		$data['id'] = $tree['memberList']['groupID64']['value'];
		$data['time'] = TIME_NOW;
		
		$cache->update("steamgroup", $data); 
	}
}

function steamgroup_global_start()
{
	global $templatelist;
	
	if(in_array(THIS_SCRIPT, explode("," ,"portal.php")))
	{
		if(isset($templatelist))
		{
			$templatelist .= ',';
		}
		
		$templatelist .= "steamgroup,steamgroup_row,steamgroup_row_noinformation";
	}
	
	if(in_array(THIS_SCRIPT, explode("," ,"index.php")))
	{
		if(isset($templatelist))
		{
			$templatelist .= ',';
		}
		
		$templatelist .= "steamgroup,steamgroup_row,steamgroup_row_noinformation";
	}
}

/********************************************************************************************************************************
*
* Say thanks to plugin author - paste link to author website.
* Please don't remove this code if you didn't make donate.
* It's the only way to say thanks without donate.
*
********************************************************************************************************************************/
function steamgroup_pre_output_page(&$content)
{
    global $session, $thanksSupryk, $lang;
	$lang->load("steamgroup");
        
    if(!isset($thanksSupryk) && $session->is_spider)
    {
        $thx = '<div style="margin:auto; text-align:center;">'.$lang->steamgroup_thanks.'</div></body>';
        $content = str_replace('</body>', $thx, $content);
        $thanksSupryk = true;
    }
}